/*
Copyright 2018 Ron Triepels

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

typedef struct {
  int top;
  int size;
  int *data;
} stack;

stack stack_init(int maxSize);

void stack_destroy(stack *s);

int stack_is_empty(stack *s);

int stack_is_full(stack *s);

void stack_push(stack *s, int x);

int stack_peek(stack *s);

void stack_remove(stack *s);

int stack_pop(stack *s);
